function OverrideWorld(inst)
	local function OverrideTuningVariables(tuning)
		if tuning then
			for k,v in pairs(tuning) do
				if GLOBAL.TUNING[k] then
					GLOBAL.TUNING[k] = v
				end
			end
		end
	end

	local difficulty_data = 
	{
		["krampus"] = GetModConfigData("krampus"),
		["wildfires"] = GetModConfigData("wildfires"),
		["deerclops"] = GetModConfigData("deerclops"),
		["bearger"] = GetModConfigData("bearger"),
		["goosemoose"] = GetModConfigData("goosemoose"),
		["dragonfly"] = GetModConfigData("dragonfly"),
		["twister"] = GetModConfigData("twister"),
		["tigershark"] = GetModConfigData("tigershark"),
		["kraken"] = GetModConfigData("kraken"),
		["liefs"] = GetModConfigData("liefs"),
		["treeguard"] = GetModConfigData("treeguard"),
		["deciduousmonster"] = GetModConfigData("deciduousmonster"),
	}

	local TUNING_OVERRIDES = 
	{
		["krampus"] = 	{
						doit = 	function(difficulty)
							local tuning_vars = {
									["never"] =  {KRAMPUS_THRESHOLD = -1, KRAMPUS_THRESHOLD_VARIANCE = 0, KRAMPUS_INCREASE_LVL1 = -1, KRAMPUS_INCREASE_LVL2 = -1, KRAMPUS_INCREASE_RAMP = -1, KRAMPUS_NAUGHTINESS_DECAY_PERIOD = 1},
									["rare"] = 	 {KRAMPUS_THRESHOLD = 45, KRAMPUS_THRESHOLD_VARIANCE = 30, KRAMPUS_INCREASE_LVL1 = 75, KRAMPUS_INCREASE_LVL2 = 125, KRAMPUS_INCREASE_RAMP = 1, KRAMPUS_NAUGHTINESS_DECAY_PERIOD = 30},
									["d efault"] =  {KRAMPUS_THRESHOLD = 30, KRAMPUS_THRESHOLD_VARIANCE = 20, KRAMPUS_INCREASE_LVL1 = 50, KRAMPUS_INCREASE_LVL2 = 100, KRAMPUS_INCREASE_RAMP = 2, KRAMPUS_NAUGHTINESS_DECAY_PERIOD = 60},
									["often"] =  {KRAMPUS_THRESHOLD = 20, KRAMPUS_THRESHOLD_VARIANCE = 15, KRAMPUS_INCREASE_LVL1 = 37, KRAMPUS_INCREASE_LVL2 = 75, KRAMPUS_INCREASE_RAMP = 3, KRAMPUS_NAUGHTINESS_DECAY_PERIOD = 90},
									["always"] = {KRAMPUS_THRESHOLD = 10, KRAMPUS_THRESHOLD_VARIANCE = 5, KRAMPUS_INCREASE_LVL1 = 25, KRAMPUS_INCREASE_LVL2 = 50, KRAMPUS_INCREASE_RAMP = 4, KRAMPUS_NAUGHTINESS_DECAY_PERIOD = 120},
									["none"] = nil
								}
							OverrideTuningVariables(tuning_vars[difficulty])
						end
					},
		["wildfires"] = {
						doit = 	function(difficulty)
							local tuning_vars = {
								["never"] = {WILDFIRE_CHANCE = -1},
								["rare"] =  {WILDFIRE_CHANCE = .1},
								["default"] =  {WILDFIRE_CHANCE = .2},
								["often"] =  {WILDFIRE_CHANCE = .4},
								["always"] =  {WILDFIRE_CHANCE = .75},
								["none"] = nil
							}
							OverrideTuningVariables(tuning_vars[difficulty])
						end
					},
		["deerclops"] = 	{
							doit = 	function(difficulty)									
								local basehassler = GLOBAL.GetWorld().components.basehassler
								if basehassler then
									if difficulty == "never" then
										basehassler:OverrideAttacksPerSeason("DEERCLOPS", 0)
										basehassler:OverrideAttackDuringOffSeason("DEERCLOPS", false)
										basehassler:OverrideAttackChance("DEERCLOPS", 0)
										basehassler:OverrideMinSpawnDay("DEERCLOPS", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "rare" then
										basehassler:OverrideAttacksPerSeason("DEERCLOPS", 1)
										basehassler:OverrideAttackDuringOffSeason("DEERCLOPS", false)
										basehassler:OverrideAttackChance("DEERCLOPS", .33)
										basehassler:OverrideMinSpawnDay("DEERCLOPS", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "default" then
										basehassler:OverrideAttacksPerSeason("DEERCLOPS", 1)
										basehassler:OverrideAttackDuringOffSeason("DEERCLOPS", false)
										basehassler:OverrideAttackChance("DEERCLOPS", .67)
										basehassler:OverrideMinSpawnDay("DEERCLOPS", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "often" then
										basehassler:OverrideAttacksPerSeason("DEERCLOPS", 1)
										basehassler:OverrideAttackDuringOffSeason("DEERCLOPS", false)
										basehassler:OverrideAttackChance("DEERCLOPS", 1.1)
										basehassler:OverrideMinSpawnDay("DEERCLOPS", nil)
									elseif difficulty == "always" then
										basehassler:OverrideAttacksPerSeason("DEERCLOPS", 1)
										basehassler:OverrideAttackDuringOffSeason("DEERCLOPS", true)
										basehassler:OverrideAttackChance("DEERCLOPS", 1.1)
										basehassler:OverrideMinSpawnDay("DEERCLOPS", nil)
									end
								end
							end,
						},
		["bearger"] = 	{
							doit = 	function(difficulty)									
								local basehassler = GLOBAL.GetWorld().components.basehassler
								if basehassler then
									if difficulty == "never" then
										basehassler:OverrideAttacksPerSeason("BEARGER", 0)
										basehassler:OverrideAttackDuringOffSeason("BEARGER", false)
										basehassler:OverrideAttackChance("BEARGER", 0)
										basehassler:OverrideMinSpawnDay("BEARGER", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "rare" then
										basehassler:OverrideAttacksPerSeason("BEARGER", 1)
										basehassler:OverrideAttackDuringOffSeason("BEARGER", false)
										basehassler:OverrideAttackChance("BEARGER", .33)
										basehassler:OverrideMinSpawnDay("BEARGER", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "default" then
										basehassler:OverrideAttacksPerSeason("BEARGER", 1)
										basehassler:OverrideAttackDuringOffSeason("BEARGER", false)
										basehassler:OverrideAttackChance("BEARGER", .67)
										basehassler:OverrideMinSpawnDay("BEARGER", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "often" then
										basehassler:OverrideAttacksPerSeason("BEARGER", 1)
										basehassler:OverrideAttackDuringOffSeason("BEARGER", false)
										basehassler:OverrideAttackChance("BEARGER", 1.1)
										basehassler:OverrideMinSpawnDay("BEARGER", nil)
									elseif difficulty == "always" then
										basehassler:OverrideAttacksPerSeason("BEARGER", 1)
										basehassler:OverrideAttackDuringOffSeason("BEARGER", true)
										basehassler:OverrideAttackChance("BEARGER", 1.1)
										basehassler:OverrideMinSpawnDay("BEARGER", nil)
									end
								end
							end,
						},
		["goosemoose"] = 	{
							doit = 	function(difficulty)									
								local basehassler = GLOBAL.GetWorld().components.basehassler
								if basehassler then
									if difficulty == "never" then
										basehassler:OverrideAttacksPerSeason("GOOSEMOOSE", 0)
										basehassler:OverrideAttackDuringOffSeason("GOOSEMOOSE", false)
										basehassler:OverrideAttackChance("GOOSEMOOSE", 0)
										basehassler:OverrideMinSpawnDay("GOOSEMOOSE", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "rare" then
										basehassler:OverrideAttacksPerSeason("GOOSEMOOSE", 1)
										basehassler:OverrideAttackDuringOffSeason("GOOSEMOOSE", false)
										basehassler:OverrideAttackChance("GOOSEMOOSE", .33)
										basehassler:OverrideMinSpawnDay("GOOSEMOOSE", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "default" then
										basehassler:OverrideAttacksPerSeason("GOOSEMOOSE", 1)
										basehassler:OverrideAttackDuringOffSeason("GOOSEMOOSE", false)
										basehassler:OverrideAttackChance("GOOSEMOOSE", .67)
										basehassler:OverrideMinSpawnDay("GOOSEMOOSE", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "often" then
										basehassler:OverrideAttacksPerSeason("GOOSEMOOSE", 1)
										basehassler:OverrideAttackDuringOffSeason("GOOSEMOOSE", false)
										basehassler:OverrideAttackChance("GOOSEMOOSE", 1.1)
										basehassler:OverrideMinSpawnDay("GOOSEMOOSE", nil)
									elseif difficulty == "always" then
										basehassler:OverrideAttacksPerSeason("GOOSEMOOSE", 1)
										basehassler:OverrideAttackDuringOffSeason("GOOSEMOOSE", true)
										basehassler:OverrideAttackChance("GOOSEMOOSE", 1.1)
										basehassler:OverrideMinSpawnDay("GOOSEMOOSE", nil)
									end
								end
							end,
						},
		["dragonfly"] = 	{
							doit = 	function(difficulty)									
								local basehassler = GLOBAL.GetWorld().components.basehassler
								if basehassler then
									if difficulty == "never" then
										basehassler:OverrideAttacksPerSeason("DRAGONFLY", 0)
										basehassler:OverrideAttackDuringOffSeason("DRAGONFLY", false)
										basehassler:OverrideAttackChance("DRAGONFLY", 0)
										basehassler:OverrideMinSpawnDay("DRAGONFLY", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "rare" then
										basehassler:OverrideAttacksPerSeason("DRAGONFLY", 1)
										basehassler:OverrideAttackDuringOffSeason("DRAGONFLY", false)
										basehassler:OverrideAttackChance("DRAGONFLY", .33)
										basehassler:OverrideMinSpawnDay("DRAGONFLY", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "default" then
										basehassler:OverrideAttacksPerSeason("DRAGONFLY", 1)
										basehassler:OverrideAttackDuringOffSeason("DRAGONFLY", false)
										basehassler:OverrideAttackChance("DRAGONFLY", .67)
										basehassler:OverrideMinSpawnDay("DRAGONFLY", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "often" then
										basehassler:OverrideAttacksPerSeason("DRAGONFLY", 1)
										basehassler:OverrideAttackDuringOffSeason("DRAGONFLY", false)
										basehassler:OverrideAttackChance("DRAGONFLY", 1.1)
										basehassler:OverrideMinSpawnDay("DRAGONFLY", nil)
									elseif difficulty == "always" then
										basehassler:OverrideAttacksPerSeason("DRAGONFLY", 1)
										basehassler:OverrideAttackDuringOffSeason("DRAGONFLY", true)
										basehassler:OverrideAttackChance("DRAGONFLY", 1.1)
										basehassler:OverrideMinSpawnDay("DRAGONFLY", nil)
									end
								end
							end,
						},
		["twister"] = 	{
							doit = 	function(difficulty)
								local basehassler = GLOBAL.GetWorld().components.basehassler
								if basehassler then
									if difficulty == "never" then
										basehassler:OverrideAttacksPerSeason("TWISTER", 0)
										basehassler:OverrideAttackDuringOffSeason("TWISTER", false)
										basehassler:OverrideAttackChance("TWISTER", 0)
										basehassler:OverrideMinSpawnDay("TWISTER", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "rare" then
										basehassler:OverrideAttacksPerSeason("TWISTER", 1)
										basehassler:OverrideAttackDuringOffSeason("TWISTER", false)
										basehassler:OverrideAttackChance("TWISTER", .33)
										basehassler:OverrideMinSpawnDay("TWISTER", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "default" then
										basehassler:OverrideAttacksPerSeason("TWISTER", 1)
										basehassler:OverrideAttackDuringOffSeason("TWISTER", false)
										basehassler:OverrideAttackChance("TWISTER", .67)
										basehassler:OverrideMinSpawnDay("TWISTER", GLOBAL.TUNING.NO_BOSS_TIME)
									elseif difficulty == "often" then
										basehassler:OverrideAttacksPerSeason("TWISTER", 1)
										basehassler:OverrideAttackDuringOffSeason("TWISTER", false)
										basehassler:OverrideAttackChance("TWISTER", 1.1)
										basehassler:OverrideMinSpawnDay("TWISTER", nil)
									elseif difficulty == "always" then
										basehassler:OverrideAttacksPerSeason("TWISTER", 1)
										basehassler:OverrideAttackDuringOffSeason("TWISTER", true)
										basehassler:OverrideAttackChance("TWISTER", 1.1)
										basehassler:OverrideMinSpawnDay("TWISTER", nil)
									end
								end
							end,
						},
		["tigershark"] = 	{
							doit = 	function(difficulty)
								local tigersharker = GLOBAL.GetWorld().components.tigersharker
								if tigersharker then
									if difficulty == "never" then
										tigersharker:SetChanceModifier(-1.0, -1.0)
										tigersharker:SetCooldownModifier(0.0, 0.0)
									elseif difficulty == "rare" then
										tigersharker:SetChanceModifier(0.5, 0.5)
										tigersharker:SetCooldownModifier(1.5, 1.5)
									elseif difficulty == "default" then
										tigersharker:SetChanceModifier(1.0, 1.0)
										tigersharker:SetCooldownModifier(1.0, 1.0)
									elseif difficulty == "often" then
										tigersharker:SetChanceModifier(1.5, 1.5)
										tigersharker:SetCooldownModifier(0.5, 0.5)
									elseif difficulty == "always" then
										tigersharker:SetChanceModifier(2.0, 2.0)
										tigersharker:SetCooldownModifier(0.25, 0.25)
									end
								end
							end,
						},
		["kraken"] = 	{
							doit = 	function(difficulty)
								local krakener = GLOBAL.GetPlayer().components.krakener
								if krakener then
									if difficulty == "never" then
										krakener:SetChanceModifier(-1.0)
										krakener:SetCooldownModifier(0.0)
									elseif difficulty == "rare" then
										krakener:SetChanceModifier(0.5)
										krakener:SetCooldownModifier(1.5)
									elseif difficulty == "default" then
										krakener:SetChanceModifier(1.0)
										krakener:SetCooldownModifier(1.0)
									elseif difficulty == "often" then
										krakener:SetChanceModifier(1.5)
										krakener:SetCooldownModifier(0.5)
									elseif difficulty == "always" then
										krakener:SetChanceModifier(2.0)
										krakener:SetCooldownModifier(0.25)
									end
								end
							end,
						},
		["liefs"] = 	{
						doit = 	function(difficulty)
							local tuning_vars = {
									["never"] =  {LEIF_MIN_DAY = 9999, LEIF_PERCENT_CHANCE = 0},
									["rare"] = 	 {LEIF_MIN_DAY = 5, LEIF_PERCENT_CHANCE = 1/100},
									["default"] =  {LEIF_MIN_DAY = 3, LEIF_PERCENT_CHANCE = 1/75},
									["often"] =  {LEIF_MIN_DAY = 2, LEIF_PERCENT_CHANCE = 1/70},
									["always"] = {LEIF_MIN_DAY = 1, LEIF_PERCENT_CHANCE = 1/55},
									["none"] =  nil,
								}
							OverrideTuningVariables(tuning_vars[difficulty])
						end
					},
		["treeguard"] = 	{
						doit = 	function(difficulty)
							local tuning_vars = {
									["never"] =  {PALMTREEGUARD_MIN_DAY = 9999, PALMTREEGUARD_PERCENT_CHANCE = 0},
									["rare"] = 	 {PALMTREEGUARD_MIN_DAY = 5, PALMTREEGUARD_PERCENT_CHANCE = 1/100},
									["default"] =  {PALMTREEGUARD_MIN_DAY = 3, PALMTREEGUARD_PERCENT_CHANCE = 1/75},
									["often"] =  {PALMTREEGUARD_MIN_DAY = 2, PALMTREEGUARD_PERCENT_CHANCE = 1/70},
									["always"] = {PALMTREEGUARD_MIN_DAY = 1, PALMTREEGUARD_PERCENT_CHANCE = 1/55},
									["none"] =  nil,
								}
							OverrideTuningVariables(tuning_vars[difficulty])
						end
					},
		["deciduousmonster"] = 	{
					doit = 	function(difficulty)
						local tuning_vars = {
								["never"] = {DECID_MONSTER_MIN_DAY = 9999, DECID_MONSTER_SPAWN_CHANCE_BASE = -1, DECID_MONSTER_SPAWN_CHANCE_LOW = -1, DECID_MONSTER_SPAWN_CHANCE_MED = -1, DECID_MONSTER_SPAWN_CHANCE_HIGH = -1},
								["rare"] = {DECID_MONSTER_MIN_DAY = 5, DECID_MONSTER_SPAWN_CHANCE_BASE = .015, DECID_MONSTER_SPAWN_CHANCE_LOW = .04, DECID_MONSTER_SPAWN_CHANCE_MED = .075, DECID_MONSTER_SPAWN_CHANCE_HIGH = .167},
								["default"] = {DECID_MONSTER_MIN_DAY = 3, DECID_MONSTER_SPAWN_CHANCE_BASE = .033, DECID_MONSTER_SPAWN_CHANCE_LOW = .08, DECID_MONSTER_SPAWN_CHANCE_MED = .15, DECID_MONSTER_SPAWN_CHANCE_HIGH = .33},
								["often"] = {DECID_MONSTER_MIN_DAY = 2, DECID_MONSTER_SPAWN_CHANCE_BASE = .07, DECID_MONSTER_SPAWN_CHANCE_LOW = .15, DECID_MONSTER_SPAWN_CHANCE_MED = .33, DECID_MONSTER_SPAWN_CHANCE_HIGH = .5},
								["always"] = {DECID_MONSTER_MIN_DAY = 1, DECID_MONSTER_SPAWN_CHANCE_BASE = .2, DECID_MONSTER_SPAWN_CHANCE_LOW = .33, DECID_MONSTER_SPAWN_CHANCE_MED = .5, DECID_MONSTER_SPAWN_CHANCE_HIGH = .67},
								["none"] =  nil,
							}
						OverrideTuningVariables(tuning_vars[difficulty])
					end,
				},

	}

	for k, v in pairs(TUNING_OVERRIDES) do
		v.doit(difficulty_data[k])
	end
end

AddSimPostInit(OverrideWorld)
